@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.02';
+$HTTP::BrowserDetect::VERSION = '2.03';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -26,6 +26,7 @@ our @WINDOWS_TESTS = qw(
     win7       win8         win8_0
     win8_1     wince        winphone
     winphone7  winphone7_5  winphone8
+    winphone8_1
 );
 
 # More precise Mac
@@ -1056,6 +1057,9 @@ sub _init_os {
             elsif ( index( $ua, "windows phone 8.0" ) != -1 ) {
                 $os_tests->{winphone8} = 1;
             }
+            elsif ( index( $ua, "windows phone 8.1" ) != -1 ) {
+                $os_tests->{winphone8_1} = 1;
+            }
         }
     }
 
@@ -1816,6 +1820,7 @@ sub _init_device {
     elsif (
         $ua =~ /windows phone os [^\)]+ iemobile\/[^;]+; ([^;]+; [^;\)]+)/g )
     {
+        # windows phone 7.x
         $device_string = substr $self->{user_agent},
             pos($ua) - length $1, length $1;
         $device_string =~ s/; / /;
@@ -1823,6 +1828,15 @@ sub _init_device {
     elsif ( $ua
         =~ /windows phone [^\)]+ iemobile\/[^;]+; arm; touch; ([^;]+; [^;\)]+)/g
         ) {
+        # windows phone 8.0
+        $device_string = substr $self->{user_agent},
+            pos($ua) - length $1, length $1;
+        $device_string =~ s/; / /;
+    }
+    elsif (
+        $ua =~ /windows phone 8[^\)]+ iemobile\/[^;]+; ([^;]+; [^;\)]+)/g ) {
+
+        # windows phone 8.1
         $device_string = substr $self->{user_agent},
             pos($ua) - length $1, length $1;
         $device_string =~ s/; / /;
@@ -2390,7 +2404,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 SYNOPSIS
 
